@@ -1,5 +1,4 @@
 import json
-from Accuinsight.modeler.core.Run.RunInfo.RunInfo import get_current_run
 from Accuinsight.modeler.core.LcConst.LcConst import RUN_BASE_PATH, RUN_PREFIX_PATH, ALL_MODEL_PARAMS, \
     SELECTED_METRICS, SELECTED_PARAMS, RUN_OBJ_MODEL_JSON_PATH
 from Accuinsight.modeler.protos.life_cycle_pb2 import LcParam, LcMetric
@@ -7,10 +6,8 @@ from Accuinsight.modeler.core.Run.ParseRun import Parse_Helper
 
 
 # load json data
-def _load_current_run():
-    run_results = {'json':'', 'visual':'', 'run_mata': ''}
-
-    run_info_json = get_current_run()
+def _load_current_run(run_info_json):
+    run_results = {'json': '', 'visual': '', 'run_mata': ''}
 
     base_path = run_info_json[RUN_BASE_PATH]
     prefix_path = run_info_json[RUN_PREFIX_PATH]
@@ -172,13 +169,10 @@ def parse_run_metrics(json_data):
 
     count = 0
     for key in metric_keys:
-        timestamp = []
-        steps = []
-        values = []
+        timestamp = [str(count)]
+        steps = [str(count)]
+        values = [str(selected_metrics[key])]
 
-        values.append(str(selected_metrics[key]))
-        timestamp.append(str(count))
-        steps.append(str(count))
         count += 1
 
         result_dict['metrics'].append({'key': key,
@@ -219,7 +213,6 @@ def _append_visual_data(visual_data, key):
         count += 1
 
         steps.append(k)
-
         values.append(v)
 
     result_dict['metrics'].append({'key': key,
@@ -236,9 +229,9 @@ def _make_steps(steps_value):
     return steps_list
 
 
-def parse_run_result():
+def parse_run_result(run_info_json):
     result_dict = {'metrics': '', 'params': ''}
-    result_data = _load_current_run()
+    result_data = _load_current_run(run_info_json)
 
     grpc_params = parse_run_parameters(json_data=result_data)
     grpc_metrics = parse_run_metrics(json_data=result_data)
